pub struct AsyncMode;Expand description
Marker type that selects async struct dispatch for IntoHandler.
Used as the Mode type parameter when a struct implementing
EventHandler<E> is passed to a subscribe_* method.