pub struct AsyncFnMode;Expand description
Marker type that selects async function dispatch for IntoHandler.
Used as the Mode type parameter when a plain async fn(E) -> HandlerResult
function pointer or closure is passed to a subscribe_* method.